==> scilab-2.1.1.tar.gz: scilab-2.1.1/routines/xsci/help/help-text2.h <==
"  Graphic   - Graphic library for Scilab  ",
"  black   - Black's diagram (Nichol's chart) ",
"  bode   - Bode plot ",
"  champ   - draw a 2d vector field  ",
"  chart   - Nichols chart ",
"  contour   - level curves of surface ",
"  driver   - select a driver for plotting ",
"  errbar   - add error tic on a graphic ",
"  eval3d   - values of a function on a grid ",
"  eval3dp   - computes facets of a 3D parametrized surface ",
"  evans   - Evans root locus ",
"  fac3d   - complex 3D surface plotting ",
"  fac3di   - 3D complex surface plotting with interactive view selection ",
"  fchamp   - draw a 2d vector field  ",
"  fcontour   - level curves ",
"  fgrayplot   - 2D plot with gray levels ",
"  fplot2d    - 2D plot of a curve defined by an external ",
"  fplot3d   - 3D plot of a surface defined by an external ",
"  fplot3d1   - gray level plotting of a surface  ",
"  gainplot   - magnitude plot ",
"  geom3d   -  projection from 3D on 2D ",
"  gr_menu   - simple interactive graphic editor ",
"  graduate   - pretty axis graduations ",
"  grayplot   - 2D plot of a surface using gray levels ",
"  hist3d   - 3D representation of an histogram ",
"  histplot   - plot an histogram ",
"  isoview   - set scales for isometric plot ",
"  locate   - mouse selection of a set of points  ",
"  m_circle   - M-circle plot ",
"  milk_drop   -  test for plot3d  ",
"  nyquist   - nyquist plot ",
"  param3d   - parametric curves in 3-D ",
"  param3di   - parametric curves in 3-D with interactive view selection ",
"  plot   - simple plot  ",
"  plot2d   - multiple plot of functions ",
"  plot2d1   - multiple plot of functions ",
"  plot2d2   - multiple plot of functions (step function) ",
"  plot2d3   - multiple plot of functions (vertical bars) ",
"  plot2d4   - multiple plot of functions ",
"  plot3d   - surface plotting ",
"  plot3d1   - gray level plotting of a surface  ",
"  plot3di   - surface plotting with interactive view selection ",
"  plot3di1   - gray level plotting of a surface with interactive view selection ",
"  plotframe   - graphic frame with scaling and grids ",
"  plzr   - pole-zero plot ",
"  printing   - printing scilab graphics  ",
"  rotate   - geometric rotation of a set of points   ",
"  scaling   - affine transform of a set of points   ",
"  secto3d   - 3D surfaces conversion ",
"  square   - sets scales for isometric graphics ",
"  titlepage    - display a matrix of strings  ",
"  xarc   - draws a part of an ellipsis  ",
"  xarcs   - drawing a set of ellipsis ",
"  xarrows   - draw a set of arrows ",
"  xaxis   - draws an axis  ",
"  xbasc   - clear the recorded graphics associated to a window ",
"  xbasimp   - send graphics to a postscript printer or in a file ",
"  xbasr   - redraw a graphic window ",
"  xchange   - coordinates transform  ",
"  xclea   - erase a rectangle on a graphic window ",
"  xclear   - clear a graphic window ",
"  xclick   - wait for a mouse click ",
"  xclip   - set a clip zone  ",
"  xend   - ends a graphic session ",
"  xfarc   - fill a part of an ellipsis  ",
"  xfpoly   - fill a polygon  ",
"  xfpolys   - fill a set of polygons of the same size  ",
"  xfrect   - fill a rectangle  ",
"  xget   - gets current values of the graphic context ",
"  xgetech   - get the current graphic 2d scale ",
"  xgetmouse   - get current position of the mouse ",
"  xgrid   - add a grid on a graphic ",
"  xinit   - initialization of a graphic driver ",
"  xlfont   - load a font in the graphic context ",
"  xnumb   - draw numbers on a graphic ",
"  xpause   - suspends Scilab  ",
"  xpoly   - draw a single polyline ",
"  xpolys   - draw a set of polylines ",
"  xrect   - draw a rectangle ",
"  xrects   - draw a set of rectangles ",
"  xrpoly   -  draw a regular polygon ",
"  xs2fig   - send graphics to a file in Xfig syntax ",
"  xsegs   - draw unconnected segments ",
"  xselect   - raise the current graphic window ",
"  xset   - set values of the graphic context ",
"  xsetech   - set the subwindow of a graphic window to use for graphics ",
"  xstring   - display a matrix of strings ",
"  xstringb   - draw a matrix of strings  ",
"  xstringl   - computes bounding box of the display of matrix of strings ",
"  xtape   -  set up the record process of graphics ",
"  xtitle   - add titles on a graphic window ",
"  zgrid   - zgrid plot ",

==> scilab_2.2.orig.tar.gz: scilab-2.2.orig/routines/xsci/help/help-text2.h <==
"  Graphic   - Graphic library for Scilab  ",
"  black   - Black's diagram (Nichol's chart) ",
"  bode   - Bode plot ",
"  champ   - draw a 2d vector field  ",
"  chart   - Nichols chart ",
"  contour   - level curves of surface ",
"  driver   - select a driver for plotting ",
"  errbar   - add error tic on a graphic ",
"  eval3d   - values of a function on a grid ",
"  eval3dp   - computes facets of a 3D parametrized surface ",
"  evans   - Evans root locus ",
"  fac3d   - complex 3D surface plotting ",
"  fchamp   - draw a 2d vector field  ",
"  fcontour   - level curves ",
"  fgrayplot   - 2D plot with gray levels ",
"  fplot2d    - 2D plot of a curve defined by an external ",
"  fplot3d   - 3D plot of a surface defined by an external ",
"  fplot3d1   - gray level plotting of a surface  ",
"  gainplot   - magnitude plot ",
"  genfac3d   - convert  3d datas to four sides facets ",
"  geom3d   -  projection from 3D on 2D ",
"  gr_menu   - simple interactive graphic editor ",
"  graduate   - pretty axis graduations ",
"  grayplot   - 2D plot of a surface using gray levels ",
"  hist3d   - 3D representation of an histogram ",
"  histplot   - plot an histogram ",
"  isoview   - set scales for isometric plot ",
"  locate   - mouse selection of a set of points  ",
"  m_circle   - M-circle plot ",
"  milk_drop   -  test for plot3d  ",
"  nyquist   - nyquist plot ",
"  param3d   - set of points or parametric curves in 3-D ",
"  param3di   - parametric curves in 3-D with interactive view selection ",
"  plot   - simple plot  ",
"  plot2d   - multiple plot of functions ",
"  plot2d1   - multiple plot of functions ",
"  plot2d2   - multiple plot of functions (step function) ",
"  plot2d3   - multiple plot of functions (vertical bars) ",
"  plot2d4   - multiple plot of functions ",
"  plot3d   - surface plotting ",
"  plot3d1   - gray level plotting of a surface  ",
"  plotframe   - graphic frame with scaling and grids ",
"  plzr   - pole-zero plot ",
"  printing   - printing scilab graphics  ",
"  rotate   - geometric rotation of a set of points   ",
"  scaling   - affine transform of a set of points   ",
"  secto3d   - 3D surfaces conversion ",
"  square   - sets scales for isometric graphics ",
"  titlepage    - display a matrix of strings  ",
"  xarc   - draws a part of an ellipsis  ",
"  xarcs   - drawing a set of ellipsis ",
"  xarrows   - draw a set of arrows ",
"  xaxis   - draws an axis  ",
"  xbasc   - clear the recorded graphics associated to a window ",
"  xbasimp   - send graphics to a postscript printer or in a file ",
"  xbasr   - redraw a graphic window ",
"  xchange   - coordinates transform  ",
"  xclea   - erase a rectangle on a graphic window ",
"  xclear   - clear a graphic window ",
"  xclick   - wait for a mouse click ",
"  xclip   - set a clip zone  ",
"  xdel   - delete a graphic window ",
"  xend   - ends a graphic session ",
"  xfarc   - fill a part of an ellipsis  ",
"  xfarcs   - drawing a set of ellipsis ",
"  xfpoly   - fill a polygon  ",
"  xfpolys   - fill a set of polygons of the same size  ",
"  xfrect   - fill a rectangle  ",
"  xget   - gets current values of the graphic context ",
"  xgetech   - get the current graphic 2d scale ",
"  xgetmouse   - get current position of the mouse ",
"  xgrid   - add a grid on a graphic ",
"  xinfo   - add an info string on a graphic window ",
"  xinit   - initialisation of a graphic driver ",
"  xlfont   - load a font in the graphic context ",
"  xload   - load a saved graphic ",
"  xnumb   - draw numbers on a graphic ",
"  xpause   - suspends Scilab  ",
"  xpoly   - draw a single polyline ",
"  xpolys   - draw a set of polylines ",
"  xrect   - draw a rectangle ",
"  xrects   - draw a set of rectangles ",
"  xrpoly   -  draw a regular polygon ",
"  xs2fig   - send graphics to a file in Xfig syntax ",
"  xsave   - save graphics in a (reloadable) file. ",
"  xsegs   - draw unconnected segments ",
"  xselect   - raise the current graphic window ",
"  xset   - set values of the graphic context ",
"  xsetech   - set the sub window of a graphic window to use for graphics ",
"  xstring   - display a matrix of strings ",
"  xstringb   - draw a matrix of strings  ",
"  xstringl   - computes bounding box of the display of matrix of strings ",
"  xtape   -  set up the record process of graphics ",
"  xtitle   - add titles on a graphic window ",
"  zgrid   - zgrid plot ",
